@@ -15,13 +15,17 @@ if [ $? -gt 0 ]; then
 	exit 1
 fi
 echo " ... selecting packages to include"
-disks=`du -sm ${MIRROR}/dists/${CODENAME}/main/disks-${ARCH}/current/. | \
-        awk '{print $1}'`
+if [ -e ${MIRROR}/dists/${CODENAME}/main/disks-${ARCH}/current/. ] ; then
+	disks=`du -sm ${MIRROR}/dists/${CODENAME}/main/disks-${ARCH}/current/. | \
+        	awk '{print $1}'`
+else
+	disks=0
+fi
 if [ -f $BASEDIR/tools/boot/$CODENAME/boot-$ARCH.calc ]; then
     . $BASEDIR/tools/boot/$CODENAME/boot-$ARCH.calc
 fi
 SIZE_ARGS=''
-for CD in 1 2 3 4; do
+for CD in 1 2 3 4 5 6 7 8; do
 	size=`eval echo '$'"BOOT_SIZE_${CD}"`
 	[ "$size" = "" ] && size=0
 	[ $CD = "1" ] && size=$(($size + $disks))
