@@ -12,22 +12,22 @@ DIR=$1
 
 DOCDIR=doc
 
-if [ -f $MIRROR/dists/$CODENAME/main/disks-$ARCH/current/images-2.88/compact/rescue.bin ] ; then
-        CODENAME1=$CODENAME
+if [ -e $BOOTDISKS/current/$DOCDIR ] ; then
+        DOCS=$BOOTDISKS/current/$DOCDIR
 else
         echo "Using potato bootdisk documentation"
-        CODENAME1=potato
+        DOCS=$MIRROR/dists/potato/main/disks-$ARCH/current/$DOCDIR
 fi
 
 
 # Put the install documentation in /install
-cd $MIRROR/dists/$CODENAME1/main/disks-$ARCH/current/$DOCDIR
-mkdir $DIR/install/$DOCDIR
+cd $DOCS
+mkdir -p $DIR/install/$DOCDIR
 cp -a * $DIR/install/$DOCDIR/
 ln -sf install.en.html $DIR/install/$DOCDIR/index.html
 
 # Put the boot-disk documentation in /doc too
-mkdir $DIR/doc/install
+mkdir -p $DIR/doc/install
 cd $DIR/doc/install
 for file in ../../install/$DOCDIR/*.{html,txt}
 do
